# Changelog

## 0.2.1 (August 2019)

* 0.2.1 is a minor update that removes the audioread depedency and directly opt for standard library for .wav and .aif support, ffmpeg for .mp3 support. 
* Bugfix for multichannels audio file loading resulting transposed columns and rows. 


## 0.2 (August 2019)

* First official PyPI release
